@@ -1,5 +1,5 @@
 use super::{RemoteProcess, RemoteProcessError, RemoteStderr, RemoteStdin, RemoteStdout};
-use crate::{client::Session, net::DataStream};
+use crate::client::Session;
 use futures::stream::{Stream, StreamExt};
 use std::{
     fmt::Write,
@@ -23,15 +23,12 @@ pub struct RemoteLspProcess {
 impl RemoteLspProcess {
     /// Spawns the specified process on the remote machine using the given session, treating
     /// the process like an LSP server
-    pub async fn spawn<T>(
-        tenant: String,
-        session: Session<T>,
-        cmd: String,
+    pub async fn spawn(
+        tenant: impl Into<String>,
+        session: &mut Session,
+        cmd: impl Into<String>,
         args: Vec<String>,
-    ) -> Result<Self, RemoteProcessError>
-    where
-        T: DataStream + 'static,
-    {
+    ) -> Result<Self, RemoteProcessError> {
         let mut inner = RemoteProcess::spawn(tenant, session, cmd, args).await?;
         let stdin = inner.stdin.take().map(RemoteLspStdin::new);
         let stdout = inner.stdout.take().map(RemoteLspStdout::new);
@@ -252,7 +249,7 @@ mod tests {
     use super::*;
     use crate::{
         data::{Request, RequestData, Response, ResponseData},
-        net::{InmemoryStream, Transport},
+        net::{InmemoryStream, PlainCodec, Transport},
     };
     use std::{future::Future, time::Duration};
 
@@ -260,15 +257,18 @@ mod tests {
     const TIMEOUT: Duration = Duration::from_millis(50);
 
     // Configures an lsp process with a means to send & receive data from outside
-    async fn spawn_lsp_process() -> (Transport<InmemoryStream>, RemoteLspProcess) {
+    async fn spawn_lsp_process() -> (Transport<InmemoryStream, PlainCodec>, RemoteLspProcess) {
         let (mut t1, t2) = Transport::make_pair();
-        let session = Session::initialize(t2).unwrap();
-        let spawn_task = tokio::spawn(RemoteLspProcess::spawn(
-            String::from("test-tenant"),
-            session,
-            String::from("cmd"),
-            vec![String::from("arg")],
-        ));
+        let mut session = Session::initialize(t2).unwrap();
+        let spawn_task = tokio::spawn(async move {
+            RemoteLspProcess::spawn(
+                String::from("test-tenant"),
+                &mut session,
+                String::from("cmd"),
+                vec![String::from("arg")],
+            )
+            .await
+        });
 
         // Wait until we get the request from the session
         let req = t1.receive::<Request>().await.unwrap().unwrap();
@@ -276,7 +276,7 @@ mod tests {
         // Send back a response through the session
         t1.send(Response::new(
             "test-tenant",
-            Some(req.id),
+            req.id,
             vec![ResponseData::ProcStart { id: rand::random() }],
         ))
         .await
@@ -520,7 +520,7 @@ mod tests {
         transport
             .send(Response::new(
                 "test-tenant",
-                None,
+                proc.origin_id,
                 vec![ResponseData::ProcStdout {
                     id: proc.id(),
                     data: make_lsp_msg(serde_json::json!({
@@ -557,7 +557,7 @@ mod tests {
         transport
             .send(Response::new(
                 "test-tenant",
-                None,
+                proc.origin_id,
                 vec![ResponseData::ProcStdout {
                     id: proc.id(),
                     data: msg_a.to_string(),
@@ -576,7 +576,7 @@ mod tests {
         transport
             .send(Response::new(
                 "test-tenant",
-                None,
+                proc.origin_id,
                 vec![ResponseData::ProcStdout {
                     id: proc.id(),
                     data: msg_b.to_string(),
@@ -611,7 +611,7 @@ mod tests {
         transport
             .send(Response::new(
                 "test-tenant",
-                None,
+                proc.origin_id,
                 vec![ResponseData::ProcStdout {
                     id: proc.id(),
                     data: format!("{}{}", msg, extra),
@@ -655,7 +655,7 @@ mod tests {
         transport
             .send(Response::new(
                 "test-tenant",
-                None,
+                proc.origin_id,
                 vec![ResponseData::ProcStdout {
                     id: proc.id(),
                     data: format!("{}{}", msg_1, msg_2),
@@ -690,7 +690,7 @@ mod tests {
         transport
             .send(Response::new(
                 "test-tenant",
-                None,
+                proc.origin_id,
                 vec![ResponseData::ProcStdout {
                     id: proc.id(),
                     data: make_lsp_msg(serde_json::json!({
@@ -721,7 +721,7 @@ mod tests {
         transport
             .send(Response::new(
                 "test-tenant",
-                None,
+                proc.origin_id,
                 vec![ResponseData::ProcStderr {
                     id: proc.id(),
                     data: make_lsp_msg(serde_json::json!({
@@ -758,7 +758,7 @@ mod tests {
         transport
             .send(Response::new(
                 "test-tenant",
-                None,
+                proc.origin_id,
                 vec![ResponseData::ProcStderr {
                     id: proc.id(),
                     data: msg_a.to_string(),
@@ -777,7 +777,7 @@ mod tests {
         transport
             .send(Response::new(
                 "test-tenant",
-                None,
+                proc.origin_id,
                 vec![ResponseData::ProcStderr {
                     id: proc.id(),
                     data: msg_b.to_string(),
@@ -812,7 +812,7 @@ mod tests {
         transport
             .send(Response::new(
                 "test-tenant",
-                None,
+                proc.origin_id,
                 vec![ResponseData::ProcStderr {
                     id: proc.id(),
                     data: format!("{}{}", msg, extra),
@@ -856,7 +856,7 @@ mod tests {
         transport
             .send(Response::new(
                 "test-tenant",
-                None,
+                proc.origin_id,
                 vec![ResponseData::ProcStderr {
                     id: proc.id(),
                     data: format!("{}{}", msg_1, msg_2),
@@ -891,7 +891,7 @@ mod tests {
         transport
             .send(Response::new(
                 "test-tenant",
-                None,
+                proc.origin_id,
                 vec![ResponseData::ProcStderr {
                     id: proc.id(),
                     data: make_lsp_msg(serde_json::json!({
