@@ -257,9 +257,9 @@ pub struct Response {
     /// A unique id associated with the response
     pub id: usize,
 
-    /// The id of the originating request, if there was one
-    /// (some responses are sent unprompted)
-    pub origin_id: Option<usize>,
+    /// The id of the originating request that yielded this response
+    /// (more than one response may have same origin)
+    pub origin_id: usize,
 
     /// The main payload containing a collection of data comprising one or more results
     pub payload: Vec<ResponseData>,
@@ -267,11 +267,7 @@ pub struct Response {
 
 impl Response {
     /// Creates a new response, generating a unique id for it
-    pub fn new(
-        tenant: impl Into<String>,
-        origin_id: Option<usize>,
-        payload: Vec<ResponseData>,
-    ) -> Self {
+    pub fn new(tenant: impl Into<String>, origin_id: usize, payload: Vec<ResponseData>) -> Self {
         let id = rand::random();
         Self {
             tenant: tenant.into(),
@@ -486,7 +482,8 @@ impl From<tokio::task::JoinError> for ResponseData {
 }
 
 /// General purpose error type that can be sent across the wire
-#[derive(Clone, Debug, PartialEq, Eq, Serialize, Deserialize)]
+#[derive(Clone, Debug, Display, PartialEq, Eq, Serialize, Deserialize)]
+#[display(fmt = "{}: {}", kind, description)]
 #[serde(rename_all = "snake_case", deny_unknown_fields)]
 pub struct Error {
     /// Label describing the kind of error
@@ -523,10 +520,8 @@ impl From<tokio::task::JoinError> for Error {
         Self {
             kind: if x.is_cancelled() {
                 ErrorKind::TaskCancelled
-            } else if x.is_panic() {
-                ErrorKind::TaskPanicked
             } else {
-                ErrorKind::Unknown
+                ErrorKind::TaskPanicked
             },
             description: format!("{}", x),
         }
@@ -597,6 +592,9 @@ pub enum ErrorKind {
     /// This operation is unsupported on this platform
     Unsupported,
 
+    /// An operation could not be completed, because it failed to allocate enough memory.
+    OutOfMemory,
+
     /// When a loop is encountered when walking a directory
     Loop,
 
@@ -632,6 +630,7 @@ impl From<io::ErrorKind> for ErrorKind {
             io::ErrorKind::Other => Self::Other,
             io::ErrorKind::UnexpectedEof => Self::UnexpectedEof,
             io::ErrorKind::Unsupported => Self::Unsupported,
+            io::ErrorKind::OutOfMemory => Self::OutOfMemory,
 
             // This exists because io::ErrorKind is non_exhaustive
             _ => Self::Unknown,
